ALTER TABLE programacion
	ADD COLUMN nProContratoId INT;
    
ALTER TABLE detalle_contrato
	ADD COLUMN sDetConSucursal VARCHAR(100) DEFAULT NULL;
    
USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `programacion_crear`;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `vpsfmsac_inspeccionesmodaservice`.`programacion_crear`;
;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE PROCEDURE `programacion_crear`(IN `pdProFecha` DATE, IN `pnProEquipo_Id` INT(11), IN `pnProTecnico_Id` INT(11), IN `pnProPlantilla_Id` INT(11), IN `pnProUsuario_Id` INT(11), IN `pnProContratoId` INT(11))
BEGIN
	INSERT INTO `programacion` (dProFecha, nProEquipo_Id, nProTecnico_Id, nProPlantilla_Id, dProFecha_Act, nProUsuario_Id, nProEstado, nProEliminado, nProContratoId) VALUES
    (pdProFecha, pnProEquipo_Id, pnProTecnico_Id, pnProPlantilla_Id, now(), pnProUsuario_Id, 1, 0, pnProContratoId);
END$$

DELIMITER ;
;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `programacion_editar`;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `vpsfmsac_inspeccionesmodaservice`.`programacion_editar`;
;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE PROCEDURE `programacion_editar`(IN `pdProFecha` DATE, IN `pnProEquipo_Id` INT(11), IN `pnProTecnico_Id` INT(11), IN `pnProPlantilla_Id` INT(11), IN `pnProUsuario_Id` INT(11), IN `pProgramacion_Id` INT(11), IN `pnProContratoId` INT(11))
BEGIN
	UPDATE programacion SET
		dProFecha = pdProFecha,
        nProEquipo_Id = pnProEquipo_Id,
        nProTecnico_Id = pnProTecnico_Id,
        nProPlantilla_Id = pnProPlantilla_Id,
        dProFecha_Act = now(),
        nProUsuario_Id = pnProUsuario_Id,
        nProEstado = 1,
        nProContratoId = pnProContratoId
	WHERE Programacion_Id = pProgramacion_Id;
END$$

DELIMITER ;
;


USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `mant_crear`;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `vpsfmsac_inspeccionesmodaservice`.`mant_crear`;
;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE PROCEDURE `mant_crear`(IN `pnManEquipo_Id` INT(11), IN `pnManTecnico_Id` INT(11), IN `psManOdometroAnterior` VARCHAR(20), IN `psManMantAnterior` VARCHAR(20), IN `psManOdometroActual` VARCHAR(20), IN `psManMantActual` VARCHAR(20), IN `psManFirmaTecnico` VARCHAR(150), IN `psManFirmaCliente` VARCHAR(150), IN `pnManUsuario_Id` INT(11), IN `pnManPlantilla_Id` INT(11), IN `pProgramacion_Id` INT, OUT `pMantenimiento_Id` INT)
BEGIN
	DECLARE auxiliar INT;
	IF pProgramacion_Id = 0 THEN
		SET auxiliar = NULL;
	ELSE
		SET auxiliar = pProgramacion_Id;
    END IF;

	INSERT INTO mantenimiento
	(`nManEquipo_Id`,
    `nManTecnico_Id`,
    `sManOdometroAnterior`,
    `sManMantAnterior`,
    `sManOdometroActual`,
    `sManMantActual`,
    `sManFirmaTecnico`,
    `sManFirmaCliente`,
    `dManFecha_Act`,
    `nManUsuario_Id`,
    `nManEstado`,
    `nManEliminado`,
    `nManPlantilla_Id`,
    `nProgramacion_Id`)
    values
    (pnManEquipo_Id,
    pnManTecnico_Id,
    psManOdometroAnterior,
    psManMantAnterior,
    psManOdometroActual,
    psManMantActual,
    psManFirmaTecnico,
    psManFirmaCliente,
    now(),
    pnManUsuario_Id,
    1,
    0,
    pnManPlantilla_Id,
    auxiliar);
    
    IF pProgramacion_Id != 0 THEN
		UPDATE programacion SET nProEstado = 2 WHERE Programacion_Id=pProgramacion_Id;
    END IF;
    
	SET pMantenimiento_Id = LAST_INSERT_ID();
    SELECT IFNULL(pMantenimiento_Id, -99) as Mantenimiento_Id;
END$$

DELIMITER ;
;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `mant_listar`;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `vpsfmsac_inspeccionesmodaservice`.`mant_listar`;
;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE PROCEDURE `mant_listar`(IN `pMantenimiento_Id` INT(11), IN `pdFechaInicio` DATE, IN `pdFechaFin` DATE)
BEGIN
	SET pdFechaFin = DATE_ADD(pdFechaFin,INTERVAL 1 DAY);
	IF pMantenimiento_Id = 0 THEN
		
		SELECT
			m.Mantenimiento_Id,
			m.nManEquipo_Id,
			m.nManTecnico_Id,
            m.sManOdometroAnterior,
			m.sManMantAnterior,
			m.sManOdometroActual,
			m.sManMantActual,
			m.sManFirmaTecnico,
			m.sManFirmaCliente,
			DATE_FORMAT(m.dManFecha_Act, '%d-%m-%Y') as dManFecha_Act,
			m.nManUsuario_Id,
			m.nManEstado,
            m.nManPlantilla_Id,
			m.nManEliminado,
            e.sEqActivoFijo,
            e.sEqSerie,
            e.sEqModelo,
            m.nProgramacion_Id,
            DATE_FORMAT(p.dProFecha, '%d-%m-%Y') as FechaProgramada,
            CASE e.nEqTipo
				WHEN 1 THEN 'GE'
				WHEN 2 THEN 'Torre'
				WHEN 3 THEN 'Compresor'
                WHEN 4 THEN 'Rodillo compactador'
				ELSE ''
			END as Tipo,
            u.sUsuNombre
        FROM mantenimiento m
        INNER JOIN equipos e ON m.nManEquipo_Id = e.Equipo_Id
        INNER JOIN usuarios u ON m.nManTecnico_Id = u.nUsuId
        LEFT JOIN programacion p ON m.nProgramacion_Id = p.Programacion_Id
		WHERE m.nManEliminado = 0
			AND m.dManFecha_Act >= pdFechaInicio
            AND m.dManFecha_Act < pdFechaFin
		ORDER BY m.Mantenimiento_Id
        ;
    ELSE
		SELECT
			m.Mantenimiento_Id,
			m.nManEquipo_Id,
			m.nManTecnico_Id,
            m.sManOdometroAnterior,
			m.sManMantAnterior,
			m.sManOdometroActual,
			m.sManMantActual,
			m.sManFirmaTecnico,
			m.sManFirmaCliente,
			DATE_FORMAT(m.dManFecha_Act, '%d-%m-%Y') as dManFecha_Act,
			m.nManUsuario_Id,
			m.nManEstado,
            m.nManPlantilla_Id,
			m.nManEliminado,
            e.sEqActivoFijo,
            e.sEqSerie,
            e.sEqModelo,
            m.nProgramacion_Id,
            cl.sCliNombre as Cliente,
            c.sConNumero as Contrato,
			dc.sDetConSucursal as Sucursal,
            dc.sDetConUbicacion as UbiPro,
            DATE_FORMAT(p.dProFecha, '%d-%m-%Y') as FechaProgramada,
            CASE e.nEqTipo
				WHEN 1 THEN 'GE'
				WHEN 2 THEN 'Torre'
				WHEN 3 THEN 'Compresor'
                WHEN 4 THEN 'Rodillo compactador'
				ELSE ''
			END as Tipo,
            u.sUsuNombre
        FROM mantenimiento m
        INNER JOIN equipos e ON m.nManEquipo_Id = e.Equipo_Id
        INNER JOIN usuarios u ON m.nManTecnico_Id = u.nUsuId       
        LEFT JOIN programacion p ON m.nProgramacion_Id = p.Programacion_Id
        LEFT JOIN contrato c ON c.Contrato_Id = p.nProContratoId
        LEFT JOIN detalle_contrato dc ON c.Contrato_Id = dc.nContrato_Id
        LEFT JOIN cliente cl ON cl.Cliente_Id = c.nConCliente_Id
		WHERE m.nManEliminado = 0 AND m.Mantenimiento_Id = pMantenimiento_Id;
    END IF;
END$$

DELIMITER ;
;


USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `eq_listar`;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `vpsfmsac_inspeccionesmodaservice`.`eq_listar`;
;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE PROCEDURE `eq_listar`(IN `pEquipo_Id` INT)
BEGIN
	IF pEquipo_Id = 0 THEN
		SELECT
			e.Equipo_Id,
			e.sEqActivoFijo,
			e.sEqModelo,
			e.sEqSerie,
			e.nEqTipo,
			e.nEqEliminado,
            e.sEqSatelite,
            e.nEqEstado
		FROM `equipos` e
		WHERE e.nEqEliminado = 0;
	ELSE
		SELECT
			e.Equipo_Id,
			e.sEqActivoFijo,
			e.sEqModelo,
			e.sEqSerie,
			e.nEqTipo,
			e.nEqEliminado,
            e.sEqSatelite,
            e.nEqEstado
		FROM `equipos` e
		WHERE e.Equipo_Id = pEquipo_Id;
	END IF;
END$$

DELIMITER ;
;


USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `eq_eliminar`;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `vpsfmsac_inspeccionesmodaservice`.`eq_eliminar`;
;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE PROCEDURE `eq_eliminar`(IN `pEquipo_Id` INT)
BEGIN
	UPDATE `equipos` SET
		nEqEstado = 0
	WHERE Equipo_Id = pEquipo_Id;
END$$

DELIMITER ;
;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `eq_crear`;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `vpsfmsac_inspeccionesmodaservice`.`eq_crear`;
;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE PROCEDURE `eq_crear`(IN `psEqActivoFijo` VARCHAR(80), IN `psEqModelo` VARCHAR(80), IN `psEqSerie` VARCHAR(30), IN `pnEqTipo` INT(11), IN `pnEqUsuario_Id` INT(11), IN `psEqSatelite` VARCHAR(150), IN `pnEqEstado` tinyint(1), OUT `pEquipo_Id` INT)
BEGIN
	INSERT INTO `equipos` (sEqActivoFijo, sEqModelo, sEqSerie, nEqTipo, nEqEliminado, dEqFecha_Act, nEqUsuario_Id, nEqEstado, sEqSatelite)
	VALUES (psEqActivoFijo, psEqModelo, psEqSerie, pnEqTipo, 0, now(), pnEqUsuario_Id, pnEqEstado, psEqSatelite);
    SET pEquipo_Id = LAST_INSERT_ID();
    SELECT IFNULL(pEquipo_Id, -99) as Equipo_Id;
END$$

DELIMITER ;
;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `eq_editar`;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `vpsfmsac_inspeccionesmodaservice`.`eq_editar`;
;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE PROCEDURE `eq_editar`(IN `psEqActivoFijo` VARCHAR(80), IN `psEqModelo` VARCHAR(80), IN `psEqSerie` VARCHAR(30), IN `pnEqTipo` INT(11), IN `pEquipo_Id` INT, IN `pnEqUsuario_Id` INT(11), IN `psEqSatelite` VARCHAR(150), IN `pnEqEstado` tinyint(1))
BEGIN
	UPDATE `equipos` SET
		sEqActivoFijo = psEqActivoFijo,
        sEqModelo = psEqModelo,
        sEqSerie = psEqSerie,
        nEqTipo = pnEqTipo,
        dEqFecha_Act = now(),
        nEqUsuario_Id = pnEqUsuario_Id,
        nEqEstado = pnEqEstado,
        sEqSatelite = psEqSatelite
	WHERE Equipo_Id = pEquipo_Id;
END$$

DELIMITER ;
;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `con_det_crear`;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `vpsfmsac_inspeccionesmodaservice`.`con_det_crear`;
;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE PROCEDURE `con_det_crear`(IN `pnContrato_Id` INT(11), IN `psDetConCodigo` VARCHAR(20), IN `psDetConSerie` VARCHAR(20), IN `psDetConTipo` VARCHAR(20), IN `psDetConUbicacion` VARCHAR(40), IN `psDetConHorasOperacion` VARCHAR(12), IN `psDetConSucursal` VARCHAR(100))
BEGIN
	INSERT INTO detalle_contrato (nContrato_Id, sDetConCodigo, sDetConSerie, sDetConTipo, sDetConUbicacion, sDetConHorasOperacion, sDetConSucursal)
    VALUES (pnContrato_Id, psDetConCodigo, psDetConSerie, psDetConTipo, psDetConUbicacion, psDetConHorasOperacion, psDetConSucursal);
END$$

DELIMITER ;
;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `con_det_buscar`;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `vpsfmsac_inspeccionesmodaservice`.`con_det_buscar`;
;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE PROCEDURE `con_det_buscar`(IN `pnContrato_Id` INT(11))
BEGIN
	SELECT
		DetalleContrato_Id,
        nContrato_Id,
        sDetConCodigo,
        sDetConSerie,
        sDetConTipo,
        sDetConUbicacion,
		sDetConHorasOperacion,
        sDetConSucursal
    FROM detalle_contrato
    WHERE nContrato_Id = pnContrato_Id;
END$$

DELIMITER ;
;


USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `eq_listarxTipo`;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE PROCEDURE `eq_listarxTipo` (IN `pnEqTipo` INT)
BEGIN
	IF pnEqTipo != 0 THEN
		SELECT
			e.Equipo_Id,
			e.sEqActivoFijo,
			e.sEqModelo,
			e.sEqSerie,
			e.nEqTipo,
			e.nEqEliminado,
			e.sEqSatelite,
			e.nEqEstado
		FROM `equipos` e
		WHERE e.nEqEliminado = 0
		AND nEqTipo = pnEqTipo;
	END IF;
END$$

DELIMITER ;


USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `programacion_listar`;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `vpsfmsac_inspeccionesmodaservice`.`programacion_listar`;
;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE PROCEDURE `programacion_listar`(IN `pProgramacion_Id` INT(11))
BEGIN
	IF pProgramacion_Id = 0 THEN
		SELECT
			p.Programacion_Id,
			p.dProFecha,
			p.nProEquipo_Id,
			p.nProTecnico_Id,
			p.nProPlantilla_Id,
			p.dProFecha_Act,
			p.nProUsuario_Id,
			p.nProEstado,
			p.nProEliminado,
            e.sEqActivoFijo,
            u.sUsuNombre,
            pl.sPlaNombre,
            p.nProContratoId
		FROM programacion p
        INNER JOIN equipos e ON p.nProEquipo_Id = e.Equipo_Id
        INNER JOIN usuarios u ON p.nProTecnico_Id = u.nUsuId
        INNER JOIN plantillas pl ON p.nProPlantilla_Id = pl.Plantilla_Id
        WHERE p.nProEliminado = 0;
	ELSE
		SELECT
			p.Programacion_Id,
			p.dProFecha,
			p.nProEquipo_Id,
			p.nProTecnico_Id,
			p.nProPlantilla_Id,
			p.dProFecha_Act,
			p.nProUsuario_Id,
			p.nProEstado,
			p.nProEliminado,
            e.sEqActivoFijo,
            u.sUsuNombre,
            pl.sPlaNombre,
            p.nProContratoId
		FROM programacion p
        INNER JOIN equipos e ON p.nProEquipo_Id = e.Equipo_Id
        INNER JOIN usuarios u ON p.nProTecnico_Id = u.nUsuId
        INNER JOIN plantillas pl ON p.nProPlantilla_Id = pl.Plantilla_Id
        WHERE p.Programacion_Id = pProgramacion_Id;
    END IF;
END$$

DELIMITER ;
;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `list_equipo_progMantenimiento`;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `vpsfmsac_inspeccionesmodaservice`.`list_equipo_progMantenimiento`;
;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE PROCEDURE `list_equipo_progMantenimiento`()
BEGIN
	SELECT
		e.*,
        p.Programacion_Id,
        p.nProTecnico_Id,
        p.dProFecha,
        p.nProContratoId
	FROM programacion p
	INNER JOIN equipos e
	ON p.nProEquipo_Id=e.Equipo_Id
	WHERE p.nProEstado = 1;
END$$

DELIMITER ;
;

USE `vpsfmsac_inspeccionesmodaservice`;
DROP procedure IF EXISTS `list_info_detallecontrato`;

DELIMITER $$
USE `vpsfmsac_inspeccionesmodaservice`$$
CREATE PROCEDURE `list_info_detallecontrato` (IN `pContrato_Id` INT(11), IN `psDetConCodigo` VARCHAR(20))
BEGIN
	SELECT dc.sDetConSucursal, dc.sDetConUbicacion, cl.sCliNombre FROM contrato c
	INNER JOIN cliente cl
	ON cl.Cliente_Id = c.nConCliente_Id
	INNER JOIN detalle_contrato dc
	ON c.Contrato_Id = dc.nContrato_Id
	WHERE c.Contrato_Id = pContrato_Id AND dc.sDetConCodigo = psDetConCodigo;
END$$

DELIMITER ;
